Minecraft Multiverse Guide 2026: Multiple Worlds on Paper 26.x

Published on | Updated

Run several worlds on one Paper 26.x server with Multiverse-Core 5.8.2: create, import, reset and unload worlds, plus portals, borders and per-world rules.

A Minecraft taiga with spruce trees on the hills beside a lake

You want more than one world on your Minecraft server: a creative world, a resource world you can reset, a lobby, a minigame map. On Paper, Multiverse-Core is the plugin for that. Many guides still show Multiverse 4 commands, and some of those fail on Multiverse 5 or on Paper 26.x. This guide uses Multiverse-Core 5.8.2, released on 26 October 2026, on Paper 26.3, and every command below is checked against each plugin's own documentation.

Quick answer: To manage multiple worlds on a Paper 26.x server, install Multiverse-Core 5.8.2, which is marked compatible with 26.3, and restart. Create each world with /mv create <name> <environment>, for example /mv create creative normal --world-type flat, go there with /mv tp creative, and change its settings with /mv modify <world> set <property> <value>, such as /mv modify creative set gamemode creative. On Paper 26.1 and newer, new worlds are stored in world/dimensions/minecraft/<name>/, not in the server root. Add Multiverse-Portals for portals, Multiverse-NetherPortals for a Nether and End per world, and Multiverse-Inventories for separate inventories.

What changed for Multiverse on Paper 26.x

If you ran Multiverse before, these five things work differently now:

Older command or habitMultiverse 5.8.2 on Paper 26.x
/mv modify set difficulty hard creative/mv modify creative set difficulty hard: the world comes before set
/mv modify set keepSpawnInMemory false resourceNot needed: Minecraft removed spawn chunks in 1.21.9, so keep-spawn-in-memory does nothing
/mv gamerule set doDaylightCycle false creative/mv gamerule set advance_time false creative: Minecraft 1.21.11 renamed the game rules
Delete a resource world and create it again/mv regen resource --seed
A world folder next to server.propertiesworld/dimensions/minecraft/<name>/

Install Multiverse-Core 5.8.2

  1. Check the Java version first: Paper 26.3 needs Java 25 or newer, according to PaperMC's download service.
  2. Download Multiverse-Core 5.8.2 from Modrinth, Hangar or Bukkit. Modrinth lists it for every version from 1.18.2 up to 26.3.
  3. Put the jar in your plugins folder and start the server. Multiverse writes its own config files on the first start; there is no zip to unpack.
  4. Run /mv version to check that 5.8.2 loaded.

The addons have to be on the same major version as Core, 5.x. On Modrinth, Multiverse-Portals 5.3.0, Multiverse-NetherPortals 5.1.0 and Multiverse-Inventories 5.3.6 all list 26.3. Multiverse also recommends a permissions plugin and names LuckPerms. New to plugins? Our plugin install guide covers the basics.

Updating a server that already runs Multiverse from 1.21.11 to 26.3? Update Multiverse to 5.8.2 first and read where Paper 26 puts your worlds before you switch the Paper jar. That guide covers the folder move, the log lines, the backup and the way back.

Create new worlds

/mv create creative normal --world-type flat
/mv create resource normal --seed 12345
/mv create minigames normal --properties gamemode=adventure,portal-form=none
/mv create resource_nether nether
  • The environment is normal, nether or the_end.
  • --world-type takes amplified, flat, large_biomes or normal, and only works with the normal environment.
  • --seed sets the seed. You cannot change it later.
  • --properties sets several world properties at once, so the world starts the way you want it.

World names cannot contain spaces. Give the world a display name with an alias instead (see below).

For a lobby, an empty void world works well. Multiverse's docs give this command, which makes a flat world of air with the the_void biome; you get only a 33 by 33 stone platform at spawn:

/mv create lobby normal --world-type flat --generator-settings {"layers":[{"block":"air","height":1}],"biome":"the_void","features":true}

Where Paper 26.x stores the new worlds

Since Paper 26.1, every world is stored as a dimension inside the main world folder: <level-name>/dimensions/<namespace>/<key>/. With the default level-name=world, the world creative lives in world/dimensions/minecraft/creative/. The name stays creative, so commands and plugins keep using that name. /mv info creative shows the key. Back up the whole world folder from now on, because it holds all your worlds.

Teleport, spawn points and a hub

/mv tp creative
/mv tp Steve creative
/mv tp e:creative:0,64,0
/mv setspawn
/mv spawn

/mv setspawn sets the world's spawn where you stand, and /mv spawn takes you back to it. The e: form is an exact destination with coordinates.

To send new players to the lobby, or every player on every login, set these in Multiverse's config:

/mv config first-spawn-override true
/mv config first-spawn-location lobby
/mv config enable-join-destination true
/mv config join-destination lobby

Players need permissions to teleport. On a new install, use-finer-teleport-permissions is on, so a player needs multiverse.teleport.self.w and also multiverse.teleport.self.w.creative to go to creative. Servers migrated from Multiverse 4 have that option off, and the first permission is enough.

Per-world settings

Every world has its own properties. The world name comes first; from the console it is required, in game it defaults to the world you are in.

/mv modify creative set gamemode creative
/mv modify creative set difficulty peaceful
/mv modify creative set pvp false
/mv modify creative set alias "&aCreative"
/mv modify survival set respawn-world lobby

Other useful properties are hunger, allow-weather, allow-flight, player-limit and portal-form. /mv modify creative reset pvp puts a property back to its default.

Mob spawning has its own command:

/mv entity-spawn-config modify creative monster set spawn false

Game rules per world

/mv gamerule list creative
/mv gamerule set advance_time false creative
/mv gamerule set keep_inventory true minigames

Minecraft 1.21.11 renamed every game rule from camel case to a namespaced ID in snake case, so keepInventory is now keep_inventory. Some got a new name as well: doDaylightCycle became advance_time, doWeatherCycle became advance_weather and doMobSpawning became spawn_mobs. doFireTick is gone, replaced by fire_spread_radius_around_player. Multiverse's own docs still show doDaylightCycle as the example, but on Paper 26.x it reads the name as a namespaced ID, and the old camel case name is rejected as not valid. Press Tab after /mv gamerule set to see the names your server accepts.

Import a world from another server

  1. Multiverse's docs ask that the world was generated on the same Minecraft version as your server. Keep a copy of the original folder either way.
  2. Upload the world folder, with its level.dat, to the server root. On Space-Node Minecraft hosting you do that with the web-based file manager, or over SFTP for worlds over 1 GB.
  3. Import it with the right environment:
/mv import arena normal

The environment must match the world, and if the world was made with a generator plugin you must pass it with --generator; Multiverse warns that bad things happen to the world otherwise. On Paper 26.1 and newer, Paper moves the folder to world/dimensions/minecraft/arena/ while it loads. For a world that already sits in the dimensions folder, pass the namespaced key instead: /mv import minecraft:arena normal. Do not rename world folders by hand; set an alias.

A Nether and an End for each world

Multiverse-NetherPortals links portals by name. Create the worlds with the suffixes _nether and _the_end, and a normal Nether portal in survival leads to survival_nether, and back:

/mv create survival_nether nether
/mv create survival_the_end the_end
/mvnp list

For a link that does not follow the names, set it yourself. --bidirectional adds the way back, and linking a world to itself turns that portal type off there:

/mvnp link nether survival resource_nether --bidirectional
/mvnp link nether minigames minigames

Coordinates scale like vanilla: the Overworld has scale 1 and the Nether scale 8, so X 800 in the Overworld becomes X 100 in the Nether. Change it with /mv modify <world> set scale <value>.

Portals between worlds

Multiverse-Portals turns any frame into a portal, even an empty one. Select two corners with /mvp wand, or with //wand if WorldEdit is installed (our WorldEdit guide covers selections), then create the portal with its destination:

/mvp create to_creative w:creative
/mvp modify to_creative dest e:@here
/mvp remove to_creative

The second line changes the destination to the exact spot where you stand, including the direction you look. Breaking the frame blocks does not delete a portal; /mvp remove does.

By default only players with multiverse.portal.access.<portalname> can use a portal, so a new portal does nothing for normal players. Give that permission per portal, or let everyone use all portals:

/mvp config enforce-portal-access false

Separate inventories per world

Multiverse-Inventories starts with one group, default, that holds world, world_nether and world_the_end and shares everything between them. Every other world gets its own inventory, so items from creative stay in creative without extra setup.

To give the resource worlds the same inventory as your main survival world, add them to that group:

/mvinv add-worlds default resource,resource_nether

A second survival world with its own Nether and End gets its own group:

/mvinv create-group smpgroup smp,smp_nether,smp_the_end all

Multiverse warns that wrong group settings can lose inventories. Back up first, and set groups up before players join those worlds.

A resource world you can reset

A resource world takes the mining and the craters away from your main world. Give it a border, generate the terrain ahead of time, and regenerate it on a schedule.

/mv worldborder center 0 0 resource
/mv worldborder set 6000 0 resource

6000 is the diameter in blocks. The 0 is the transition time, so the border is set at once. If you use vanilla /worldborder instead, note that since 1.21.11 a plain number for the time means ticks, not seconds.

Then pre-generate the area inside the border with Chunky:

/chunky world resource
/chunky worldborder
/chunky start

Our Chunky pre-generation guide explains the settings.

To reset the world:

/mv regen resource --seed

--seed without a value picks a new random seed; leave it out to rebuild the same terrain. The world keeps its Multiverse settings, game rules and border unless you add --reset-world-config, --reset-gamerules or --reset-world-border. If players are still inside, the command stops with an error; /mv regen resource --remove-players lobby sends them to the lobby during the rebuild and back afterwards. Announce resets in advance, run them in a quiet hour, and run Chunky again after each reset.

Paper can also refill loot chests in that world only. Its per-world config file sits in the world's folder, so add this to world/dimensions/minecraft/resource/paper-world.yml and restart:

lootables:
  auto-replenish: true

Copy only the lines you change. Everything else comes from config/paper-world-defaults.yml.

Other plugins, per world

WorldGuard gives every world its own global region, __global__. Version 7.0.21 came out on 3 November 2026 for 26.3. To stop building in the whole lobby except for members:

/rg flag __global__ passthrough -w lobby deny
/rg addmember -w lobby __global__ g:builder

LuckPerms uses the world context for the world a player is in. This gives the builder group WorldEdit in creative only:

/lp group builder permission set worldedit.* true world=creative

Unload worlds you rarely use

CommandUnloads the worldRemoves it from worlds.ymlDeletes the folder
/mv unload eventYesNoNo
/mv remove eventYesYesNo
/mv delete eventYesYesYes, after /mv confirm within 30 seconds

Multiverse suggests unloading rarely used worlds for performance. /mv load event brings an unloaded world back, and /mv modify event set auto-load false keeps it unloaded after a restart, so an event map only runs on event days. Spawn chunks are no longer a cost: Minecraft removed them in 1.21.9.

FAQ

Does Multiverse work on Minecraft 26.3?

Yes. Multiverse-Core 5.8.2, released on 26 October 2026, is marked compatible with 26.3, and Portals 5.3.0, NetherPortals 5.1.0 and Inventories 5.3.6 all list 26.3 on Modrinth. Keep all modules on 5.x.

Where are my Multiverse worlds stored on Paper 26.x?

In world/dimensions/minecraft/<name>/ with the default level-name=world. Worlds from before 26.1 move there on their first load; our Paper 26 migration guide explains the move.

Why can't players use /mv tp or my portal?

Permissions. New installs need both multiverse.teleport.self.w and multiverse.teleport.self.w.<world>, and portals need multiverse.portal.access.<portalname> unless you turn off enforce-portal-access.

How do I reset a resource world without deleting it?

/mv regen resource --seed rebuilds it with a new seed and keeps its settings and border. Without --seed it keeps the same seed.

Can each world have its own inventory?

Yes, with Multiverse-Inventories. Worlds outside the default group get their own inventory automatically; use /mvinv add-worlds or /mvinv create-group to share.

Is keep-spawn-in-memory still useful?

No. Multiverse's docs say the setting has no effect on 1.21.9 or later, because Minecraft removed spawn chunks.

Sources

All opened on 3 November 2026: